@@ -12,14 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-use protobuf::Message;
+//! Protocol structs for Purchase Order transaction payloads
+
+use protobuf::{Message, RepeatedField};
 
 use crate::protocol::errors::BuilderError;
+use crate::protocol::purchase_order::state::PurchaseOrderAlternateId;
+use crate::protos;
 use crate::protos::purchase_order_payload;
 use crate::protos::{
     FromBytes, FromNative, FromProto, IntoBytes, IntoNative, IntoProto, ProtoConversionError,
 };
 
+/// The Purchase Order payload's action envelope
 #[derive(Debug, Clone, PartialEq)]
 pub enum Action {
     CreatePo(CreatePurchaseOrderPayload),
@@ -28,11 +33,10 @@ pub enum Action {
     UpdateVersion(UpdateVersionPayload),
 }
 
+/// Native representation of a Purchase Order payload
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderPayload {
     action: Action,
-    org_id: String,
-    public_key: String,
     timestamp: u64,
 }
 
@@ -41,14 +45,6 @@ impl PurchaseOrderPayload {
         &self.action
     }
 
-    pub fn org_id(&self) -> &str {
-        &self.org_id
-    }
-
-    pub fn public_key(&self) -> &str {
-        &self.public_key
-    }
-
     pub fn timestamp(&self) -> u64 {
         self.timestamp
     }
@@ -83,8 +79,6 @@ impl FromProto<purchase_order_payload::PurchaseOrderPayload> for PurchaseOrderPa
         };
         Ok(PurchaseOrderPayload {
             action,
-            org_id: payload.take_org_id(),
-            public_key: payload.take_public_key(),
             timestamp: payload.get_timestamp(),
         })
     }
@@ -93,10 +87,7 @@ impl FromProto<purchase_order_payload::PurchaseOrderPayload> for PurchaseOrderPa
 impl FromNative<PurchaseOrderPayload> for purchase_order_payload::PurchaseOrderPayload {
     fn from_native(native: PurchaseOrderPayload) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::PurchaseOrderPayload::new();
-
         proto.set_timestamp(native.timestamp());
-        proto.set_org_id(native.org_id().to_string());
-        proto.set_public_key(native.public_key().to_string());
 
         match native.action() {
             Action::CreatePo(payload) => {
@@ -152,11 +143,10 @@ impl IntoBytes for PurchaseOrderPayload {
 impl IntoProto<purchase_order_payload::PurchaseOrderPayload> for PurchaseOrderPayload {}
 impl IntoNative<PurchaseOrderPayload> for purchase_order_payload::PurchaseOrderPayload {}
 
+/// Builder used to create a Purchase Order payload
 #[derive(Default, Clone)]
 pub struct PurchaseOrderPayloadBuilder {
     action: Option<Action>,
-    org_id: Option<String>,
-    public_key: Option<String>,
     timestamp: Option<u64>,
 }
 
@@ -170,16 +160,6 @@ impl PurchaseOrderPayloadBuilder {
         self
     }
 
-    pub fn with_org_id(mut self, org_id: String) -> Self {
-        self.org_id = Some(org_id);
-        self
-    }
-
-    pub fn with_public_key(mut self, public_key: String) -> Self {
-        self.public_key = Some(public_key);
-        self
-    }
-
     pub fn with_timestamp(mut self, value: u64) -> Self {
         self.timestamp = Some(value);
         self
@@ -190,50 +170,91 @@ impl PurchaseOrderPayloadBuilder {
             .action
             .ok_or_else(|| BuilderError::MissingField("'action' field is required".into()))?;
 
-        let org_id = self
-            .org_id
-            .ok_or_else(|| BuilderError::MissingField("'org_id' field is required".into()))?;
-
-        let public_key = self
-            .public_key
-            .ok_or_else(|| BuilderError::MissingField("'public_key' field is required".into()))?;
-
         let timestamp = self
             .timestamp
             .ok_or_else(|| BuilderError::MissingField("'timestamp' field is required".into()))?;
 
-        Ok(PurchaseOrderPayload {
-            action,
-            org_id,
-            public_key,
-            timestamp,
-        })
+        Ok(PurchaseOrderPayload { action, timestamp })
     }
 }
 
+/// Native representation of the "create purchase order" payload
 #[derive(Debug, Default, Clone, PartialEq)]
 pub struct CreatePurchaseOrderPayload {
-    uuid: String,
+    uid: String,
     created_at: u64,
+    buyer_org_id: String,
+    seller_org_id: String,
+    workflow_state: String,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
+    create_version_payload: Option<CreateVersionPayload>,
+    workflow_id: String,
 }
 
 impl CreatePurchaseOrderPayload {
-    pub fn uuid(&self) -> &str {
-        &self.uuid
+    pub fn uid(&self) -> &str {
+        &self.uid
     }
 
     pub fn created_at(&self) -> u64 {
         self.created_at
     }
+
+    pub fn buyer_org_id(&self) -> &str {
+        &self.buyer_org_id
+    }
+
+    pub fn seller_org_id(&self) -> &str {
+        &self.seller_org_id
+    }
+
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
+    }
+
+    pub fn alternate_ids(&self) -> &[PurchaseOrderAlternateId] {
+        &self.alternate_ids
+    }
+
+    pub fn create_version_payload(&self) -> Option<CreateVersionPayload> {
+        self.create_version_payload.clone()
+    }
+
+    pub fn workflow_id(&self) -> &str {
+        &self.workflow_id
+    }
 }
 
 impl FromProto<purchase_order_payload::CreatePurchaseOrderPayload> for CreatePurchaseOrderPayload {
     fn from_proto(
         mut proto: purchase_order_payload::CreatePurchaseOrderPayload,
     ) -> Result<Self, ProtoConversionError> {
+        let create_version_payload = if proto
+            .get_create_version_payload()
+            .get_version_id()
+            .is_empty()
+        {
+            None
+        } else {
+            Some(CreateVersionPayload::from_proto(
+                proto.take_create_version_payload(),
+            )?)
+        };
+
         Ok(CreatePurchaseOrderPayload {
-            uuid: proto.take_uuid(),
+            uid: proto.take_uid(),
             created_at: proto.get_created_at(),
+            buyer_org_id: proto.take_buyer_org_id(),
+            seller_org_id: proto.take_seller_org_id(),
+            workflow_state: proto.take_workflow_state(),
+            alternate_ids: proto
+                .get_alternate_ids()
+                .to_vec()
+                .into_iter()
+                .map(PurchaseOrderAlternateId::from_proto)
+                .collect::<Result<Vec<PurchaseOrderAlternateId>, ProtoConversionError>>()?,
+            create_version_payload,
+            workflow_id: proto.take_workflow_id(),
         })
     }
 }
@@ -241,8 +262,29 @@ impl FromProto<purchase_order_payload::CreatePurchaseOrderPayload> for CreatePur
 impl FromNative<CreatePurchaseOrderPayload> for purchase_order_payload::CreatePurchaseOrderPayload {
     fn from_native(native: CreatePurchaseOrderPayload) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::CreatePurchaseOrderPayload::new();
-        proto.set_uuid(native.uuid().to_string());
+        proto.set_uid(native.uid().to_string());
         proto.set_created_at(native.created_at());
+        proto.set_buyer_org_id(native.buyer_org_id().to_string());
+        proto.set_seller_org_id(native.seller_org_id().to_string());
+        proto.set_alternate_ids(RepeatedField::from_vec(
+            native
+                .alternate_ids()
+                .to_vec()
+                .into_iter()
+                .map(PurchaseOrderAlternateId::into_proto)
+                .collect::<Result<
+                    Vec<protos::purchase_order_state::PurchaseOrderAlternateId>,
+                    ProtoConversionError,
+                >>()?,
+        ));
+        proto.set_workflow_state(native.workflow_state().to_string());
+        proto.set_workflow_id(native.workflow_id().to_string());
+
+        if let Some(payload) = native.create_version_payload() {
+            let proto_payload: purchase_order_payload::CreateVersionPayload =
+                payload.into_proto()?;
+            proto.set_create_version_payload(proto_payload);
+        }
 
         Ok(proto)
     }
@@ -275,10 +317,17 @@ impl IntoBytes for CreatePurchaseOrderPayload {
 impl IntoProto<purchase_order_payload::CreatePurchaseOrderPayload> for CreatePurchaseOrderPayload {}
 impl IntoNative<CreatePurchaseOrderPayload> for purchase_order_payload::CreatePurchaseOrderPayload {}
 
+/// Builder used to create the "create purchase order" payload
 #[derive(Default, Debug)]
 pub struct CreatePurchaseOrderPayloadBuilder {
-    uuid: Option<String>,
+    uid: Option<String>,
     created_at: Option<u64>,
+    buyer_org_id: Option<String>,
+    seller_org_id: Option<String>,
+    workflow_state: Option<String>,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
+    create_version_payload: Option<CreateVersionPayload>,
+    workflow_id: Option<String>,
 }
 
 impl CreatePurchaseOrderPayloadBuilder {
@@ -286,8 +335,8 @@ impl CreatePurchaseOrderPayloadBuilder {
         CreatePurchaseOrderPayloadBuilder::default()
     }
 
-    pub fn with_uuid(mut self, value: String) -> Self {
-        self.uuid = Some(value);
+    pub fn with_uid(mut self, value: String) -> Self {
+        self.uid = Some(value);
         self
     }
 
@@ -296,37 +345,112 @@ impl CreatePurchaseOrderPayloadBuilder {
         self
     }
 
+    pub fn with_buyer_org_id(mut self, value: String) -> Self {
+        self.buyer_org_id = Some(value);
+        self
+    }
+
+    pub fn with_seller_org_id(mut self, value: String) -> Self {
+        self.seller_org_id = Some(value);
+        self
+    }
+
+    pub fn with_workflow_state(mut self, value: String) -> Self {
+        self.workflow_state = Some(value);
+        self
+    }
+
+    pub fn with_alternate_ids(mut self, alternate_ids: Vec<PurchaseOrderAlternateId>) -> Self {
+        self.alternate_ids = alternate_ids;
+        self
+    }
+
+    pub fn with_create_version_payload(mut self, payload: CreateVersionPayload) -> Self {
+        self.create_version_payload = Some(payload);
+        self
+    }
+
+    pub fn with_workflow_id(mut self, value: String) -> Self {
+        self.workflow_id = Some(value);
+        self
+    }
+
     pub fn build(self) -> Result<CreatePurchaseOrderPayload, BuilderError> {
-        let uuid = self
-            .uuid
-            .ok_or_else(|| BuilderError::MissingField("'uuid' field is required".to_string()))?;
+        let uid = self
+            .uid
+            .ok_or_else(|| BuilderError::MissingField("'uid' field is required".to_string()))?;
 
         let created_at = self.created_at.ok_or_else(|| {
             BuilderError::MissingField("'created_at' field is required".to_string())
         })?;
 
-        Ok(CreatePurchaseOrderPayload { uuid, created_at })
+        let buyer_org_id = self.buyer_org_id.ok_or_else(|| {
+            BuilderError::MissingField("'buyer_org_id' field is required".to_string())
+        })?;
+
+        let seller_org_id = self.seller_org_id.ok_or_else(|| {
+            BuilderError::MissingField("'seller_org_id' field is required".to_string())
+        })?;
+
+        let workflow_state = self.workflow_state.ok_or_else(|| {
+            BuilderError::MissingField("'workflow_state' field is required".to_string())
+        })?;
+
+        let alternate_ids = self.alternate_ids;
+
+        let create_version_payload = self.create_version_payload;
+
+        let workflow_id = self.workflow_id.ok_or_else(|| {
+            BuilderError::MissingField("'workflow_id' field is required".to_string())
+        })?;
+
+        Ok(CreatePurchaseOrderPayload {
+            uid,
+            created_at,
+            buyer_org_id,
+            seller_org_id,
+            workflow_state,
+            alternate_ids,
+            create_version_payload,
+            workflow_id,
+        })
     }
 }
 
+/// Native representation of the "update purchase order" payload
 #[derive(Debug, Default, Clone, PartialEq)]
 pub struct UpdatePurchaseOrderPayload {
-    workflow_status: String,
+    uid: String,
+    workflow_state: String,
     is_closed: bool,
-    accepted_version_number: String,
+    accepted_version_number: Option<String>,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
+    version_updates: Vec<UpdateVersionPayload>,
 }
 
 impl UpdatePurchaseOrderPayload {
-    pub fn workflow_status(&self) -> &str {
-        &self.workflow_status
+    pub fn uid(&self) -> &str {
+        &self.uid
+    }
+
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
     }
 
     pub fn is_closed(&self) -> bool {
         self.is_closed
     }
 
-    pub fn accepted_version_number(&self) -> &str {
-        &self.accepted_version_number
+    pub fn accepted_version_number(&self) -> Option<&str> {
+        self.accepted_version_number.as_deref()
+    }
+
+    pub fn alternate_ids(&self) -> &[PurchaseOrderAlternateId] {
+        &self.alternate_ids
+    }
+
+    pub fn version_updates(&self) -> &[UpdateVersionPayload] {
+        &self.version_updates
     }
 }
 
@@ -335,9 +459,25 @@ impl FromProto<purchase_order_payload::UpdatePurchaseOrderPayload> for UpdatePur
         mut proto: purchase_order_payload::UpdatePurchaseOrderPayload,
     ) -> Result<Self, ProtoConversionError> {
         Ok(UpdatePurchaseOrderPayload {
-            workflow_status: proto.take_workflow_status(),
+            uid: proto.take_po_uid(),
+            workflow_state: proto.take_workflow_state(),
             is_closed: proto.get_is_closed(),
-            accepted_version_number: proto.take_accepted_version_number(),
+            accepted_version_number: match proto.get_accepted_version_number().is_empty() {
+                false => Some(proto.take_accepted_version_number()),
+                true => None,
+            },
+            alternate_ids: proto
+                .get_alternate_ids()
+                .to_vec()
+                .into_iter()
+                .map(PurchaseOrderAlternateId::from_proto)
+                .collect::<Result<Vec<PurchaseOrderAlternateId>, ProtoConversionError>>()?,
+            version_updates: proto
+                .get_version_updates()
+                .to_vec()
+                .into_iter()
+                .map(UpdateVersionPayload::from_proto)
+                .collect::<Result<Vec<UpdateVersionPayload>, ProtoConversionError>>()?,
         })
     }
 }
@@ -345,10 +485,34 @@ impl FromProto<purchase_order_payload::UpdatePurchaseOrderPayload> for UpdatePur
 impl FromNative<UpdatePurchaseOrderPayload> for purchase_order_payload::UpdatePurchaseOrderPayload {
     fn from_native(native: UpdatePurchaseOrderPayload) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::UpdatePurchaseOrderPayload::new();
-        proto.set_workflow_status(native.workflow_status().to_string());
+        proto.set_po_uid(native.uid().to_string());
+        proto.set_workflow_state(native.workflow_state().to_string());
         proto.set_is_closed(native.is_closed());
-        proto.set_accepted_version_number(native.accepted_version_number().to_string());
-
+        proto.set_accepted_version_number(
+            native.accepted_version_number().unwrap_or("").to_string(),
+        );
+        proto.set_alternate_ids(RepeatedField::from_vec(
+            native
+                .alternate_ids()
+                .to_vec()
+                .into_iter()
+                .map(PurchaseOrderAlternateId::into_proto)
+                .collect::<Result<
+                    Vec<protos::purchase_order_state::PurchaseOrderAlternateId>,
+                    ProtoConversionError,
+                >>()?,
+        ));
+        proto.set_version_updates(RepeatedField::from_vec(
+            native
+                .version_updates()
+                .to_vec()
+                .into_iter()
+                .map(UpdateVersionPayload::into_proto)
+                .collect::<Result<
+                    Vec<protos::purchase_order_payload::UpdateVersionPayload>,
+                    ProtoConversionError,
+                >>()?,
+        ));
         Ok(proto)
     }
 }
@@ -380,11 +544,15 @@ impl IntoBytes for UpdatePurchaseOrderPayload {
 impl IntoProto<purchase_order_payload::UpdatePurchaseOrderPayload> for UpdatePurchaseOrderPayload {}
 impl IntoNative<UpdatePurchaseOrderPayload> for purchase_order_payload::UpdatePurchaseOrderPayload {}
 
+/// Builder used to create the "update purchase order" payload
 #[derive(Default, Debug)]
 pub struct UpdatePurchaseOrderPayloadBuilder {
-    workflow_status: Option<String>,
+    uid: Option<String>,
+    workflow_state: Option<String>,
     is_closed: Option<bool>,
     accepted_version_number: Option<String>,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
+    version_updates: Vec<UpdateVersionPayload>,
 }
 
 impl UpdatePurchaseOrderPayloadBuilder {
@@ -392,8 +560,13 @@ impl UpdatePurchaseOrderPayloadBuilder {
         UpdatePurchaseOrderPayloadBuilder::default()
     }
 
-    pub fn with_workflow_status(mut self, value: String) -> Self {
-        self.workflow_status = Some(value);
+    pub fn with_uid(mut self, value: String) -> Self {
+        self.uid = Some(value);
+        self
+    }
+
+    pub fn with_workflow_state(mut self, value: String) -> Self {
+        self.workflow_state = Some(value);
         self
     }
 
@@ -402,43 +575,61 @@ impl UpdatePurchaseOrderPayloadBuilder {
         self
     }
 
-    pub fn with_accepted_version_number(mut self, value: String) -> Self {
-        self.accepted_version_number = Some(value);
+    pub fn with_accepted_version_number(mut self, value: Option<String>) -> Self {
+        self.accepted_version_number = value;
+        self
+    }
+
+    pub fn with_alternate_ids(mut self, value: Vec<PurchaseOrderAlternateId>) -> Self {
+        self.alternate_ids = value;
+        self
+    }
+
+    pub fn with_version_updates(mut self, value: Vec<UpdateVersionPayload>) -> Self {
+        self.version_updates = value;
         self
     }
 
     pub fn build(self) -> Result<UpdatePurchaseOrderPayload, BuilderError> {
-        let workflow_status = self.workflow_status.ok_or_else(|| {
-            BuilderError::MissingField("'workflow_status' field is required".to_string())
+        let uid = self
+            .uid
+            .ok_or_else(|| BuilderError::MissingField("'uid' field is required".to_string()))?;
+
+        let workflow_state = self.workflow_state.ok_or_else(|| {
+            BuilderError::MissingField("'workflow_state' field is required".to_string())
         })?;
 
         let is_closed = self.is_closed.ok_or_else(|| {
             BuilderError::MissingField("'is_closed' field is required".to_string())
         })?;
 
-        let accepted_version_number = self.accepted_version_number.ok_or_else(|| {
-            BuilderError::MissingField("'accepted_version_number' field is required".to_string())
-        })?;
+        let alternate_ids = self.alternate_ids;
+
+        let version_updates = self.version_updates;
 
         Ok(UpdatePurchaseOrderPayload {
-            workflow_status,
+            uid,
+            workflow_state,
             is_closed,
-            accepted_version_number,
+            accepted_version_number: self.accepted_version_number,
+            alternate_ids,
+            version_updates,
         })
     }
 }
 
+/// Native representation of the revision made in a "create" or "update" version payload
 #[derive(Debug, Default, Clone, PartialEq)]
 pub struct PayloadRevision {
-    revision_id: String,
+    revision_id: u64,
     submitter: String,
     created_at: u64,
     order_xml_v3_4: String,
 }
 
 impl PayloadRevision {
-    pub fn revision_id(&self) -> &str {
-        &self.revision_id
+    pub fn revision_id(&self) -> u64 {
+        self.revision_id
     }
 
     pub fn submitter(&self) -> &str {
@@ -459,7 +650,7 @@ impl FromProto<purchase_order_payload::PayloadRevision> for PayloadRevision {
         mut proto: purchase_order_payload::PayloadRevision,
     ) -> Result<Self, ProtoConversionError> {
         Ok(PayloadRevision {
-            revision_id: proto.take_revision_id(),
+            revision_id: proto.get_revision_id(),
             submitter: proto.take_submitter(),
             created_at: proto.get_created_at(),
             order_xml_v3_4: proto.take_order_xml_v3_4(),
@@ -470,7 +661,7 @@ impl FromProto<purchase_order_payload::PayloadRevision> for PayloadRevision {
 impl FromNative<PayloadRevision> for purchase_order_payload::PayloadRevision {
     fn from_native(native: PayloadRevision) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::PayloadRevision::new();
-        proto.set_revision_id(native.revision_id().to_string());
+        proto.set_revision_id(native.revision_id());
         proto.set_submitter(native.submitter().to_string());
         proto.set_created_at(native.created_at());
         proto.set_order_xml_v3_4(native.order_xml_v3_4().to_string());
@@ -506,9 +697,10 @@ impl IntoBytes for PayloadRevision {
 impl IntoProto<purchase_order_payload::PayloadRevision> for PayloadRevision {}
 impl IntoNative<PayloadRevision> for purchase_order_payload::PayloadRevision {}
 
+/// Builder used to create the revision object made in a "create" or "update" version payload
 #[derive(Default, Debug)]
 pub struct PayloadRevisionBuilder {
-    revision_id: Option<String>,
+    revision_id: Option<u64>,
     submitter: Option<String>,
     created_at: Option<u64>,
     order_xml_v3_4: Option<String>,
@@ -519,7 +711,7 @@ impl PayloadRevisionBuilder {
         PayloadRevisionBuilder::default()
     }
 
-    pub fn with_revision_id(mut self, value: String) -> Self {
+    pub fn with_revision_id(mut self, value: u64) -> Self {
         self.revision_id = Some(value);
         self
     }
@@ -565,10 +757,13 @@ impl PayloadRevisionBuilder {
     }
 }
 
+/// Native representation of the "create version" payload
 #[derive(Debug, Default, Clone, PartialEq)]
 pub struct CreateVersionPayload {
     version_id: String,
+    po_uid: String,
     is_draft: bool,
+    workflow_state: String,
     revision: PayloadRevision,
 }
 
@@ -577,10 +772,18 @@ impl CreateVersionPayload {
         &self.version_id
     }
 
+    pub fn po_uid(&self) -> &str {
+        &self.po_uid
+    }
+
     pub fn is_draft(&self) -> bool {
         self.is_draft
     }
 
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
+    }
+
     pub fn revision(&self) -> &PayloadRevision {
         &self.revision
     }
@@ -592,7 +795,9 @@ impl FromProto<purchase_order_payload::CreateVersionPayload> for CreateVersionPa
     ) -> Result<Self, ProtoConversionError> {
         Ok(CreateVersionPayload {
             version_id: proto.take_version_id(),
+            po_uid: proto.take_po_uid(),
             is_draft: proto.get_is_draft(),
+            workflow_state: proto.take_workflow_state(),
             revision: PayloadRevision::from_proto(proto.take_revision())?,
         })
     }
@@ -602,7 +807,9 @@ impl FromNative<CreateVersionPayload> for purchase_order_payload::CreateVersionP
     fn from_native(native: CreateVersionPayload) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::CreateVersionPayload::new();
         proto.set_version_id(native.version_id().to_string());
+        proto.set_po_uid(native.po_uid().to_string());
         proto.set_is_draft(native.is_draft());
+        proto.set_workflow_state(native.workflow_state().to_string());
         proto.set_revision(native.revision().clone().into_proto()?);
 
         Ok(proto)
@@ -636,10 +843,13 @@ impl IntoBytes for CreateVersionPayload {
 impl IntoProto<purchase_order_payload::CreateVersionPayload> for CreateVersionPayload {}
 impl IntoNative<CreateVersionPayload> for purchase_order_payload::CreateVersionPayload {}
 
+/// Builder used to create a "create version" payload
 #[derive(Default, Debug)]
 pub struct CreateVersionPayloadBuilder {
     version_id: Option<String>,
+    po_uid: Option<String>,
     is_draft: Option<bool>,
+    workflow_state: Option<String>,
     revision: Option<PayloadRevision>,
 }
 
@@ -653,11 +863,21 @@ impl CreateVersionPayloadBuilder {
         self
     }
 
+    pub fn with_po_uid(mut self, value: String) -> Self {
+        self.po_uid = Some(value);
+        self
+    }
+
     pub fn with_is_draft(mut self, value: bool) -> Self {
         self.is_draft = Some(value);
         self
     }
 
+    pub fn with_workflow_state(mut self, value: String) -> Self {
+        self.workflow_state = Some(value);
+        self
+    }
+
     pub fn with_revision(mut self, value: PayloadRevision) -> Self {
         self.revision = Some(value);
         self
@@ -668,28 +888,39 @@ impl CreateVersionPayloadBuilder {
             BuilderError::MissingField("'version_id' field is required".to_string())
         })?;
 
+        let po_uid = self
+            .po_uid
+            .ok_or_else(|| BuilderError::MissingField("'po_uid' field is required".to_string()))?;
+
         let is_draft = self.is_draft.ok_or_else(|| {
             BuilderError::MissingField("'is_draft' field is required".to_string())
         })?;
 
+        let workflow_state = self.workflow_state.ok_or_else(|| {
+            BuilderError::MissingField("'workflow_state' field is required".to_string())
+        })?;
+
         let revision = self.revision.ok_or_else(|| {
             BuilderError::MissingField("'revision' field is required".to_string())
         })?;
 
         Ok(CreateVersionPayload {
             version_id,
+            po_uid,
             is_draft,
+            workflow_state,
             revision,
         })
     }
 }
 
+/// Native representation of the "update version" payload
 #[derive(Debug, Default, Clone, PartialEq)]
 pub struct UpdateVersionPayload {
     version_id: String,
-    workflow_status: String,
+    po_uid: String,
+    workflow_state: String,
     is_draft: bool,
-    current_revision_id: String,
     revision: PayloadRevision,
 }
 
@@ -698,18 +929,18 @@ impl UpdateVersionPayload {
         &self.version_id
     }
 
-    pub fn workflow_status(&self) -> &str {
-        &self.workflow_status
+    pub fn po_uid(&self) -> &str {
+        &self.po_uid
+    }
+
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
     }
 
     pub fn is_draft(&self) -> bool {
         self.is_draft
     }
 
-    pub fn current_revision_id(&self) -> &str {
-        &self.current_revision_id
-    }
-
     pub fn revision(&self) -> &PayloadRevision {
         &self.revision
     }
@@ -721,9 +952,9 @@ impl FromProto<purchase_order_payload::UpdateVersionPayload> for UpdateVersionPa
     ) -> Result<Self, ProtoConversionError> {
         Ok(UpdateVersionPayload {
             version_id: proto.take_version_id(),
-            workflow_status: proto.take_workflow_status(),
+            po_uid: proto.take_po_uid(),
+            workflow_state: proto.take_workflow_state(),
             is_draft: proto.get_is_draft(),
-            current_revision_id: proto.take_current_revision_id(),
             revision: PayloadRevision::from_proto(proto.take_revision())?,
         })
     }
@@ -733,9 +964,9 @@ impl FromNative<UpdateVersionPayload> for purchase_order_payload::UpdateVersionP
     fn from_native(native: UpdateVersionPayload) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_payload::UpdateVersionPayload::new();
         proto.set_version_id(native.version_id().to_string());
-        proto.set_workflow_status(native.workflow_status().to_string());
+        proto.set_po_uid(native.po_uid().to_string());
+        proto.set_workflow_state(native.workflow_state().to_string());
         proto.set_is_draft(native.is_draft());
-        proto.set_current_revision_id(native.current_revision_id().to_string());
         proto.set_revision(native.revision().clone().into_proto()?);
 
         Ok(proto)
@@ -769,12 +1000,13 @@ impl IntoBytes for UpdateVersionPayload {
 impl IntoProto<purchase_order_payload::UpdateVersionPayload> for UpdateVersionPayload {}
 impl IntoNative<UpdateVersionPayload> for purchase_order_payload::UpdateVersionPayload {}
 
+/// Builder used to create the "update version" payload
 #[derive(Default, Debug)]
 pub struct UpdateVersionPayloadBuilder {
     version_id: Option<String>,
-    workflow_status: Option<String>,
+    po_uid: Option<String>,
+    workflow_state: Option<String>,
     is_draft: Option<bool>,
-    current_revision_id: Option<String>,
     revision: Option<PayloadRevision>,
 }
 
@@ -788,8 +1020,13 @@ impl UpdateVersionPayloadBuilder {
         self
     }
 
-    pub fn with_workflow_status(mut self, value: String) -> Self {
-        self.workflow_status = Some(value);
+    pub fn with_po_uid(mut self, value: String) -> Self {
+        self.po_uid = Some(value);
+        self
+    }
+
+    pub fn with_workflow_state(mut self, value: String) -> Self {
+        self.workflow_state = Some(value);
         self
     }
 
@@ -798,11 +1035,6 @@ impl UpdateVersionPayloadBuilder {
         self
     }
 
-    pub fn with_current_revision_id(mut self, value: String) -> Self {
-        self.current_revision_id = Some(value);
-        self
-    }
-
     pub fn with_revision(mut self, value: PayloadRevision) -> Self {
         self.revision = Some(value);
         self
@@ -813,28 +1045,125 @@ impl UpdateVersionPayloadBuilder {
             BuilderError::MissingField("'version_id' field is required".to_string())
         })?;
 
-        let workflow_status = self.workflow_status.ok_or_else(|| {
-            BuilderError::MissingField("'workflow_status' field is required".to_string())
+        let po_uid = self
+            .po_uid
+            .ok_or_else(|| BuilderError::MissingField("'po_uid' field is required".to_string()))?;
+
+        let workflow_state = self.workflow_state.ok_or_else(|| {
+            BuilderError::MissingField("'workflow_state' field is required".to_string())
         })?;
 
         let is_draft = self.is_draft.ok_or_else(|| {
             BuilderError::MissingField("'is_draft' field is required".to_string())
         })?;
 
-        let current_revision_id = self.current_revision_id.ok_or_else(|| {
-            BuilderError::MissingField("'current_revision_id' field is required".to_string())
-        })?;
-
         let revision = self.revision.ok_or_else(|| {
             BuilderError::MissingField("'revision' field is required".to_string())
         })?;
 
         Ok(UpdateVersionPayload {
             version_id,
-            workflow_status,
+            po_uid,
+            workflow_state,
             is_draft,
-            current_revision_id,
             revision,
         })
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::*;
+    use crate::protocol::purchase_order::state::PurchaseOrderAlternateIdBuilder;
+
+    /// Validate UpdatePurchaseOrderPayload protobuf translates to native
+    #[test]
+    fn update_po_transforms_to_update_po_protobuf_correctly() {
+        let alternate_ids = vec![PurchaseOrderAlternateIdBuilder::new()
+            .with_id_type("type".to_string())
+            .with_id("id".to_string())
+            .with_purchase_order_uid("uid".to_string())
+            .build()
+            .unwrap()];
+
+        // Validate with all fields filled out
+        let proto_update_po = UpdatePurchaseOrderPayload {
+            uid: "uid".to_string(),
+            workflow_state: "status".to_string(),
+            is_closed: true,
+            accepted_version_number: Some("version".to_string()),
+            alternate_ids,
+            version_updates: Vec::new(),
+        }
+        .into_proto()
+        .expect("could not transform into proto");
+        assert_eq!(proto_update_po.get_po_uid(), "uid");
+        assert_eq!(proto_update_po.get_workflow_state(), "status");
+        assert!(proto_update_po.get_is_closed());
+        assert_eq!(proto_update_po.get_accepted_version_number(), "version");
+        assert!(proto_update_po.get_version_updates().is_empty());
+
+        // Validate with optional fields not filled out
+        let proto_update_po = UpdatePurchaseOrderPayload {
+            uid: "uid".to_string(),
+            workflow_state: "status".to_string(),
+            is_closed: true,
+            accepted_version_number: None,
+            alternate_ids: Vec::new(),
+            version_updates: Vec::new(),
+        }
+        .into_proto()
+        .expect("could not transform into proto");
+        assert_eq!(proto_update_po.get_accepted_version_number(), "");
+    }
+
+    /// Validate UpdatePurchaseOrderPayload native translates to protobuf
+    #[test]
+    fn update_po_protobuf_transforms_to_update_po_correctly() {
+        let alternate_ids = vec![PurchaseOrderAlternateIdBuilder::new()
+            .with_id_type("type".to_string())
+            .with_id("id".to_string())
+            .with_purchase_order_uid("uid".to_string())
+            .build()
+            .unwrap()
+            .into_proto()
+            .unwrap()];
+
+        // Validate with all fields filled out
+        let mut proto_update_po = purchase_order_payload::UpdatePurchaseOrderPayload::new();
+        proto_update_po.set_po_uid("uid".to_string());
+        proto_update_po.set_workflow_state("status".to_string());
+        proto_update_po.set_is_closed(true);
+        proto_update_po.set_accepted_version_number("version".to_string());
+        proto_update_po.set_alternate_ids(RepeatedField::from(alternate_ids.to_vec()));
+
+        let update_po = proto_update_po
+            .into_native()
+            .expect("could not transform into native");
+        assert_eq!(update_po.uid(), "uid");
+        assert_eq!(update_po.workflow_state(), "status");
+        assert!(update_po.is_closed());
+        assert_eq!(update_po.accepted_version_number(), Some("version"));
+        assert_eq!(
+            update_po.alternate_ids(),
+            alternate_ids
+                .to_vec()
+                .into_iter()
+                .map(|id| PurchaseOrderAlternateId::from_proto(id).unwrap())
+                .collect::<Vec<PurchaseOrderAlternateId>>()
+        );
+
+        // Validate with optional fields not filled out
+        let mut proto_update_po = purchase_order_payload::UpdatePurchaseOrderPayload::new();
+        proto_update_po.set_po_uid("uid".to_string());
+        proto_update_po.set_workflow_state("status".to_string());
+        proto_update_po.set_is_closed(true);
+        proto_update_po.set_accepted_version_number("".to_string());
+
+        let update_po = proto_update_po
+            .into_native()
+            .expect("could not transform into native");
+        assert_eq!(update_po.accepted_version_number(), None);
+        assert_eq!(update_po.alternate_ids(), Vec::new());
+    }
+}
