@@ -12,6 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+//! Protocol structs for Purchase Order state
+
 use protobuf::Message;
 use protobuf::RepeatedField;
 
@@ -22,17 +24,20 @@ use crate::protos::{
     FromBytes, FromNative, FromProto, IntoBytes, IntoNative, IntoProto, ProtoConversionError,
 };
 
+/// Native representation of a `PurchaseOrderRevision`
+///
+/// The purchase order revision contains the editable fields of a purchase order
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderRevision {
-    revision_id: String,
+    revision_id: u64,
     submitter: String,
     created_at: u64,
     order_xml_v3_4: String,
 }
 
 impl PurchaseOrderRevision {
-    pub fn revision_id(&self) -> &str {
-        &self.revision_id
+    pub fn revision_id(&self) -> u64 {
+        self.revision_id
     }
 
     pub fn submitter(&self) -> &str {
@@ -61,7 +66,7 @@ impl FromProto<purchase_order_state::PurchaseOrderRevision> for PurchaseOrderRev
         mut revision: purchase_order_state::PurchaseOrderRevision,
     ) -> Result<Self, ProtoConversionError> {
         Ok(PurchaseOrderRevision {
-            revision_id: revision.take_revision_id(),
+            revision_id: revision.get_revision_id(),
             submitter: revision.take_submitter(),
             created_at: revision.get_created_at(),
             order_xml_v3_4: revision.take_order_xml_v3_4(),
@@ -72,7 +77,7 @@ impl FromProto<purchase_order_state::PurchaseOrderRevision> for PurchaseOrderRev
 impl FromNative<PurchaseOrderRevision> for purchase_order_state::PurchaseOrderRevision {
     fn from_native(revision: PurchaseOrderRevision) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_state::PurchaseOrderRevision::new();
-        proto.set_revision_id(revision.revision_id().to_string());
+        proto.set_revision_id(revision.revision_id());
         proto.set_submitter(revision.submitter().to_string());
         proto.set_created_at(revision.created_at());
         proto.set_order_xml_v3_4(revision.order_xml_v3_4().to_string());
@@ -97,6 +102,8 @@ impl IntoBytes for PurchaseOrderRevision {
 impl IntoProto<purchase_order_state::PurchaseOrderRevision> for PurchaseOrderRevision {}
 impl IntoNative<PurchaseOrderRevision> for purchase_order_state::PurchaseOrderRevision {}
 
+/// Returned if any required fields in a `PurchaseOrderRevision` are not present when being
+/// converted from the corresponding builder
 #[derive(Debug)]
 pub enum PurchaseOrderRevisionBuildError {
     MissingField(String),
@@ -120,9 +127,10 @@ impl std::fmt::Display for PurchaseOrderRevisionBuildError {
     }
 }
 
+/// Builder used to create a `PurchaseOrderRevision`
 #[derive(Default, Clone, PartialEq)]
 pub struct PurchaseOrderRevisionBuilder {
-    revision_id: Option<String>,
+    revision_id: Option<u64>,
     submitter: Option<String>,
     created_at: Option<u64>,
     order_xml_v3_4: Option<String>,
@@ -133,7 +141,7 @@ impl PurchaseOrderRevisionBuilder {
         PurchaseOrderRevisionBuilder::default()
     }
 
-    pub fn with_revision_id(mut self, revision_id: String) -> Self {
+    pub fn with_revision_id(mut self, revision_id: u64) -> Self {
         self.revision_id = Some(revision_id);
         self
     }
@@ -187,13 +195,17 @@ impl PurchaseOrderRevisionBuilder {
     }
 }
 
+/// Native representation of a `PurchaseOrderVersion`
+///
+/// A purchase order version is created everytime updates are made to the purchase order, requiring
+/// a new version of the original
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderVersion {
     version_id: String,
-    workflow_status: String,
+    workflow_state: String,
     is_draft: bool,
-    current_revision_id: String,
-    revisions: PurchaseOrderRevision,
+    current_revision_id: u64,
+    revisions: Vec<PurchaseOrderRevision>,
 }
 
 impl PurchaseOrderVersion {
@@ -201,26 +213,26 @@ impl PurchaseOrderVersion {
         &self.version_id
     }
 
-    pub fn workflow_status(&self) -> &str {
-        &self.workflow_status
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
     }
 
     pub fn is_draft(&self) -> bool {
         self.is_draft
     }
 
-    pub fn current_revision_id(&self) -> &str {
-        &self.current_revision_id
+    pub fn current_revision_id(&self) -> u64 {
+        self.current_revision_id
     }
 
-    pub fn revisions(&self) -> &PurchaseOrderRevision {
+    pub fn revisions(&self) -> &[PurchaseOrderRevision] {
         &self.revisions
     }
 
     pub fn into_builder(self) -> PurchaseOrderVersionBuilder {
         PurchaseOrderVersionBuilder::new()
             .with_version_id(self.version_id)
-            .with_workflow_status(self.workflow_status)
+            .with_workflow_state(self.workflow_state)
             .with_is_draft(self.is_draft)
             .with_current_revision_id(self.current_revision_id)
             .with_revisions(self.revisions)
@@ -233,10 +245,14 @@ impl FromProto<purchase_order_state::PurchaseOrderVersion> for PurchaseOrderVers
     ) -> Result<Self, ProtoConversionError> {
         Ok(PurchaseOrderVersion {
             version_id: version.take_version_id(),
-            workflow_status: version.take_workflow_status(),
+            workflow_state: version.take_workflow_state(),
             is_draft: version.get_is_draft(),
-            current_revision_id: version.take_current_revision_id(),
-            revisions: PurchaseOrderRevision::from_proto(version.take_revisions())?,
+            current_revision_id: version.get_current_revision_id(),
+            revisions: version
+                .take_revisions()
+                .into_iter()
+                .map(PurchaseOrderRevision::from_proto)
+                .collect::<Result<_, _>>()?,
         })
     }
 }
@@ -245,10 +261,17 @@ impl FromNative<PurchaseOrderVersion> for purchase_order_state::PurchaseOrderVer
     fn from_native(version: PurchaseOrderVersion) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_state::PurchaseOrderVersion::new();
         proto.set_version_id(version.version_id().to_string());
-        proto.set_workflow_status(version.workflow_status().to_string());
+        proto.set_workflow_state(version.workflow_state().to_string());
         proto.set_is_draft(version.is_draft());
-        proto.set_current_revision_id(version.current_revision_id().to_string());
-        proto.set_revisions(version.revisions().clone().into_proto()?);
+        proto.set_current_revision_id(version.current_revision_id());
+        proto.set_revisions(RepeatedField::from_vec(
+            version
+                .revisions()
+                .to_vec()
+                .into_iter()
+                .map(|revision| revision.into_proto())
+                .collect::<Result<_, _>>()?,
+        ));
 
         Ok(proto)
     }
@@ -270,6 +293,8 @@ impl IntoBytes for PurchaseOrderVersion {
 impl IntoProto<purchase_order_state::PurchaseOrderVersion> for PurchaseOrderVersion {}
 impl IntoNative<PurchaseOrderVersion> for purchase_order_state::PurchaseOrderVersion {}
 
+/// Returned if any required fields in a `PurchaseOrderVersion` are not present when being
+/// converted from the corresponding builder
 #[derive(Debug)]
 pub enum PurchaseOrderVersionBuildError {
     MissingField(String),
@@ -293,13 +318,14 @@ impl std::fmt::Display for PurchaseOrderVersionBuildError {
     }
 }
 
+/// Builder used to create a `PurchaseOrderVersion`
 #[derive(Default, Clone, PartialEq)]
 pub struct PurchaseOrderVersionBuilder {
     version_id: Option<String>,
-    workflow_status: Option<String>,
+    workflow_state: Option<String>,
     is_draft: Option<bool>,
-    current_revision_id: Option<String>,
-    revisions: Option<PurchaseOrderRevision>,
+    current_revision_id: Option<u64>,
+    revisions: Option<Vec<PurchaseOrderRevision>>,
 }
 
 impl PurchaseOrderVersionBuilder {
@@ -312,8 +338,8 @@ impl PurchaseOrderVersionBuilder {
         self
     }
 
-    pub fn with_workflow_status(mut self, workflow_status: String) -> Self {
-        self.workflow_status = Some(workflow_status);
+    pub fn with_workflow_state(mut self, workflow_state: String) -> Self {
+        self.workflow_state = Some(workflow_state);
         self
     }
 
@@ -322,12 +348,12 @@ impl PurchaseOrderVersionBuilder {
         self
     }
 
-    pub fn with_current_revision_id(mut self, current_revision_id: String) -> Self {
+    pub fn with_current_revision_id(mut self, current_revision_id: u64) -> Self {
         self.current_revision_id = Some(current_revision_id);
         self
     }
 
-    pub fn with_revisions(mut self, revisions: PurchaseOrderRevision) -> Self {
+    pub fn with_revisions(mut self, revisions: Vec<PurchaseOrderRevision>) -> Self {
         self.revisions = Some(revisions);
         self
     }
@@ -339,9 +365,9 @@ impl PurchaseOrderVersionBuilder {
             )
         })?;
 
-        let workflow_status = self.workflow_status.ok_or_else(|| {
+        let workflow_state = self.workflow_state.ok_or_else(|| {
             PurchaseOrderVersionBuildError::MissingField(
-                "'workflow_status' field is required".to_string(),
+                "'workflow_state' field is required".to_string(),
             )
         })?;
 
@@ -363,7 +389,7 @@ impl PurchaseOrderVersionBuilder {
 
         Ok(PurchaseOrderVersion {
             version_id,
-            workflow_status,
+            workflow_state,
             is_draft,
             current_revision_id,
             revisions,
@@ -371,31 +397,42 @@ impl PurchaseOrderVersionBuilder {
     }
 }
 
+/// Native representation of a `PurchaseOrder`
+///
+/// Purchase orders in real-life trade scenarios are represented by `PurchaseOrder`
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrder {
-    uuid: String,
-    workflow_status: String,
+    uid: String,
+    workflow_state: String,
     versions: Vec<PurchaseOrderVersion>,
-    accepted_version_number: String,
+    accepted_version_number: Option<String>,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
     created_at: u64,
     is_closed: bool,
+    buyer_org_id: String,
+    seller_org_id: String,
+    workflow_id: String,
 }
 
 impl PurchaseOrder {
-    pub fn uuid(&self) -> &str {
-        &self.uuid
+    pub fn uid(&self) -> &str {
+        &self.uid
     }
 
-    pub fn workflow_status(&self) -> &str {
-        &self.workflow_status
+    pub fn workflow_state(&self) -> &str {
+        &self.workflow_state
     }
 
     pub fn versions(&self) -> &[PurchaseOrderVersion] {
         &self.versions
     }
 
-    pub fn accepted_version_number(&self) -> &str {
-        &self.accepted_version_number
+    pub fn accepted_version_number(&self) -> Option<&str> {
+        self.accepted_version_number.as_deref()
+    }
+
+    pub fn alternate_ids(&self) -> &[PurchaseOrderAlternateId] {
+        &self.alternate_ids
     }
 
     pub fn created_at(&self) -> u64 {
@@ -406,14 +443,35 @@ impl PurchaseOrder {
         self.is_closed
     }
 
+    pub fn buyer_org_id(&self) -> &str {
+        &self.buyer_org_id
+    }
+
+    pub fn seller_org_id(&self) -> &str {
+        &self.seller_org_id
+    }
+
+    pub fn workflow_id(&self) -> &str {
+        &self.workflow_id
+    }
+
     pub fn into_builder(self) -> PurchaseOrderBuilder {
-        PurchaseOrderBuilder::new()
-            .with_uuid(self.uuid)
-            .with_workflow_status(self.workflow_status)
+        let mut builder = PurchaseOrderBuilder::new()
+            .with_uid(self.uid)
+            .with_workflow_state(self.workflow_state)
             .with_versions(self.versions)
-            .with_accepted_version_number(self.accepted_version_number)
             .with_created_at(self.created_at)
+            .with_alternate_ids(self.alternate_ids)
             .with_is_closed(self.is_closed)
+            .with_buyer_org_id(self.buyer_org_id)
+            .with_seller_org_id(self.seller_org_id)
+            .with_workflow_id(self.workflow_id);
+
+        if let Some(accepted_version) = self.accepted_version_number {
+            builder = builder.with_accepted_version_number(accepted_version);
+        }
+
+        builder
     }
 }
 
@@ -421,17 +479,33 @@ impl FromProto<purchase_order_state::PurchaseOrder> for PurchaseOrder {
     fn from_proto(
         mut order: purchase_order_state::PurchaseOrder,
     ) -> Result<Self, ProtoConversionError> {
+        let accepted_version_number = {
+            let accepted_version = order.take_accepted_version_number();
+            if accepted_version.is_empty() {
+                None
+            } else {
+                Some(accepted_version)
+            }
+        };
         Ok(PurchaseOrder {
-            uuid: order.take_uuid(),
-            workflow_status: order.take_workflow_status(),
+            uid: order.take_uid(),
+            workflow_state: order.take_workflow_state(),
             versions: order
                 .take_versions()
                 .into_iter()
                 .map(PurchaseOrderVersion::from_proto)
                 .collect::<Result<_, _>>()?,
-            accepted_version_number: order.take_accepted_version_number(),
+            accepted_version_number,
             created_at: order.get_created_at(),
+            alternate_ids: order
+                .take_alternate_ids()
+                .into_iter()
+                .map(PurchaseOrderAlternateId::from_proto)
+                .collect::<Result<_, _>>()?,
             is_closed: order.get_is_closed(),
+            buyer_org_id: order.take_buyer_org_id(),
+            seller_org_id: order.take_seller_org_id(),
+            workflow_id: order.take_workflow_id(),
         })
     }
 }
@@ -439,8 +513,8 @@ impl FromProto<purchase_order_state::PurchaseOrder> for PurchaseOrder {
 impl FromNative<PurchaseOrder> for purchase_order_state::PurchaseOrder {
     fn from_native(order: PurchaseOrder) -> Result<Self, ProtoConversionError> {
         let mut proto = purchase_order_state::PurchaseOrder::new();
-        proto.set_uuid(order.uuid().to_string());
-        proto.set_workflow_status(order.workflow_status().to_string());
+        proto.set_uid(order.uid().to_string());
+        proto.set_workflow_state(order.workflow_state().to_string());
         proto.set_versions(RepeatedField::from_vec(
             order
                 .versions()
@@ -449,9 +523,22 @@ impl FromNative<PurchaseOrder> for purchase_order_state::PurchaseOrder {
                 .map(|version| version.into_proto())
                 .collect::<Result<_, _>>()?,
         ));
-        proto.set_accepted_version_number(order.accepted_version_number().to_string());
+        if let Some(accepted_version) = order.accepted_version_number() {
+            proto.set_accepted_version_number(accepted_version.to_string());
+        }
         proto.set_created_at(order.created_at());
+        proto.set_alternate_ids(RepeatedField::from_vec(
+            order
+                .alternate_ids()
+                .to_vec()
+                .into_iter()
+                .map(|id| id.into_proto())
+                .collect::<Result<_, _>>()?,
+        ));
         proto.set_is_closed(order.is_closed());
+        proto.set_buyer_org_id(order.buyer_org_id().to_string());
+        proto.set_seller_org_id(order.seller_org_id().to_string());
+        proto.set_workflow_id(order.workflow_id().to_string());
 
         Ok(proto)
     }
@@ -473,6 +560,8 @@ impl IntoBytes for PurchaseOrder {
 impl IntoProto<purchase_order_state::PurchaseOrder> for PurchaseOrder {}
 impl IntoNative<PurchaseOrder> for purchase_order_state::PurchaseOrder {}
 
+/// Returned if any required fields in a `PurchaseOrder` are not present when being converted from
+/// the corresponding builder
 #[derive(Debug)]
 pub enum PurchaseOrderBuildError {
     MissingField(String),
@@ -497,14 +586,19 @@ impl std::fmt::Display for PurchaseOrderBuildError {
     }
 }
 
+/// Builder used to create a `PurchaseOrder`
 #[derive(Default, Clone, PartialEq)]
 pub struct PurchaseOrderBuilder {
-    uuid: Option<String>,
-    workflow_status: Option<String>,
+    uid: Option<String>,
+    workflow_state: Option<String>,
     versions: Option<Vec<PurchaseOrderVersion>>,
     accepted_version_number: Option<String>,
     created_at: Option<u64>,
+    alternate_ids: Vec<PurchaseOrderAlternateId>,
     is_closed: Option<bool>,
+    buyer_org_id: Option<String>,
+    seller_org_id: Option<String>,
+    workflow_id: Option<String>,
 }
 
 impl PurchaseOrderBuilder {
@@ -512,13 +606,13 @@ impl PurchaseOrderBuilder {
         PurchaseOrderBuilder::default()
     }
 
-    pub fn with_uuid(mut self, uuid: String) -> Self {
-        self.uuid = Some(uuid);
+    pub fn with_uid(mut self, uid: String) -> Self {
+        self.uid = Some(uid);
         self
     }
 
-    pub fn with_workflow_status(mut self, workflow_status: String) -> Self {
-        self.workflow_status = Some(workflow_status);
+    pub fn with_workflow_state(mut self, workflow_state: String) -> Self {
+        self.workflow_state = Some(workflow_state);
         self
     }
 
@@ -537,49 +631,84 @@ impl PurchaseOrderBuilder {
         self
     }
 
+    pub fn with_alternate_ids(mut self, alternate_ids: Vec<PurchaseOrderAlternateId>) -> Self {
+        self.alternate_ids = alternate_ids;
+        self
+    }
+
     pub fn with_is_closed(mut self, is_closed: bool) -> Self {
         self.is_closed = Some(is_closed);
         self
     }
 
+    pub fn with_buyer_org_id(mut self, buyer: String) -> Self {
+        self.buyer_org_id = Some(buyer);
+        self
+    }
+
+    pub fn with_seller_org_id(mut self, seller: String) -> Self {
+        self.seller_org_id = Some(seller);
+        self
+    }
+
+    pub fn with_workflow_id(mut self, workflow_id: String) -> Self {
+        self.workflow_id = Some(workflow_id);
+        self
+    }
+
     pub fn build(self) -> Result<PurchaseOrder, PurchaseOrderBuildError> {
-        let uuid = self.uuid.ok_or_else(|| {
-            PurchaseOrderBuildError::MissingField("'uuid' field is required".to_string())
+        let uid = self.uid.ok_or_else(|| {
+            PurchaseOrderBuildError::MissingField("'uid' field is required".to_string())
         })?;
 
-        let workflow_status = self.workflow_status.ok_or_else(|| {
-            PurchaseOrderBuildError::MissingField("'workflow_status' field is required".to_string())
+        let workflow_state = self.workflow_state.ok_or_else(|| {
+            PurchaseOrderBuildError::MissingField("'workflow_state' field is required".to_string())
         })?;
 
         let versions = self.versions.ok_or_else(|| {
             PurchaseOrderBuildError::EmptyVec("'versions' field is required".to_string())
         })?;
 
-        let accepted_version_number = self.accepted_version_number.ok_or_else(|| {
-            PurchaseOrderBuildError::MissingField(
-                "'accepted_version_number' field is required".to_string(),
-            )
-        })?;
+        let accepted_version_number = self.accepted_version_number;
 
         let created_at = self.created_at.ok_or_else(|| {
             PurchaseOrderBuildError::MissingField("'created_at' field is required".to_string())
         })?;
 
+        let alternate_ids = self.alternate_ids;
+
         let is_closed = self.is_closed.ok_or_else(|| {
             PurchaseOrderBuildError::MissingField("'is_closed' field is required".to_string())
         })?;
 
+        let buyer_org_id = self.buyer_org_id.ok_or_else(|| {
+            PurchaseOrderBuildError::MissingField("'buyer_org_id' field is required".to_string())
+        })?;
+
+        let seller_org_id = self.seller_org_id.ok_or_else(|| {
+            PurchaseOrderBuildError::MissingField("'seller_org_id' field is required".to_string())
+        })?;
+
+        let workflow_id = self.workflow_id.ok_or_else(|| {
+            PurchaseOrderBuildError::MissingField("'workflow_id' field is required".to_string())
+        })?;
+
         Ok(PurchaseOrder {
-            uuid,
-            workflow_status,
+            uid,
+            workflow_state,
             versions,
             accepted_version_number,
             created_at,
+            alternate_ids,
             is_closed,
+            buyer_org_id,
+            seller_org_id,
+            workflow_id,
         })
     }
 }
 
+/// Native representation of a list of `PurchaseOrder`s
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderList {
     purchase_orders: Vec<PurchaseOrder>,
@@ -657,6 +786,7 @@ impl IntoBytes for PurchaseOrderList {
 impl IntoProto<purchase_order_state::PurchaseOrderList> for PurchaseOrderList {}
 impl IntoNative<PurchaseOrderList> for purchase_order_state::PurchaseOrderList {}
 
+/// Builder used to create a list of `PurchaseOrder`s
 #[derive(Default, Clone)]
 pub struct PurchaseOrderListBuilder {
     purchase_orders: Option<Vec<PurchaseOrder>>,
@@ -691,14 +821,27 @@ impl PurchaseOrderListBuilder {
     }
 }
 
+/// Native representation of a `PurchaseOrderAlternateId`
+///
+/// An `AlternateId` is a separate identifier from the `PurchaseOrder`'s unique
+/// identifier. This enables certain smart contracts to identify a
+/// `PurchaseOrder` within its own context.
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderAlternateId {
     id_type: String,
     id: String,
-    org_id: String,
+    purchase_order_uid: String,
 }
 
 impl PurchaseOrderAlternateId {
+    pub fn new(purchase_order_uid: &str, alternate_id_type: &str, alternate_id: &str) -> Self {
+        Self {
+            purchase_order_uid: purchase_order_uid.to_string(),
+            id_type: alternate_id_type.to_string(),
+            id: alternate_id.to_string(),
+        }
+    }
+
     pub fn id_type(&self) -> &str {
         &self.id_type
     }
@@ -707,15 +850,15 @@ impl PurchaseOrderAlternateId {
         &self.id
     }
 
-    pub fn org_id(&self) -> &str {
-        &self.org_id
+    pub fn purchase_order_uid(&self) -> &str {
+        &self.purchase_order_uid
     }
 
     pub fn into_builder(self) -> PurchaseOrderAlternateIdBuilder {
         PurchaseOrderAlternateIdBuilder::new()
             .with_id_type(self.id_type)
             .with_id(self.id)
-            .with_org_id(self.org_id)
+            .with_purchase_order_uid(self.purchase_order_uid)
     }
 }
 
@@ -726,7 +869,7 @@ impl FromProto<purchase_order_state::PurchaseOrderAlternateId> for PurchaseOrder
         Ok(PurchaseOrderAlternateId {
             id_type: alt_id.take_id_type(),
             id: alt_id.take_id(),
-            org_id: alt_id.take_org_id(),
+            purchase_order_uid: alt_id.take_po_uid(),
         })
     }
 }
@@ -736,7 +879,7 @@ impl FromNative<PurchaseOrderAlternateId> for purchase_order_state::PurchaseOrde
         let mut proto = purchase_order_state::PurchaseOrderAlternateId::new();
         proto.set_id_type(alt_id.id_type().to_string());
         proto.set_id(alt_id.id().to_string());
-        proto.set_org_id(alt_id.org_id().to_string());
+        proto.set_po_uid(alt_id.purchase_order_uid().to_string());
 
         Ok(proto)
     }
@@ -758,6 +901,8 @@ impl IntoBytes for PurchaseOrderAlternateId {
 impl IntoProto<purchase_order_state::PurchaseOrderAlternateId> for PurchaseOrderAlternateId {}
 impl IntoNative<PurchaseOrderAlternateId> for purchase_order_state::PurchaseOrderAlternateId {}
 
+/// Returned if any required fields in a `PurchaseOrderAlternateId` are not present when being
+/// converted from the corresponding builder
 #[derive(Debug)]
 pub enum PurchaseOrderAlternateIdBuildError {
     MissingField(String),
@@ -786,11 +931,12 @@ impl std::fmt::Display for PurchaseOrderAlternateIdBuildError {
     }
 }
 
+/// Builder used to create a `PurchaseOrderAlternateId`
 #[derive(Default, Clone, PartialEq)]
 pub struct PurchaseOrderAlternateIdBuilder {
     id_type: Option<String>,
     id: Option<String>,
-    org_id: Option<String>,
+    purchase_order_uid: Option<String>,
 }
 
 impl PurchaseOrderAlternateIdBuilder {
@@ -808,8 +954,8 @@ impl PurchaseOrderAlternateIdBuilder {
         self
     }
 
-    pub fn with_org_id(mut self, org_id: String) -> Self {
-        self.org_id = Some(org_id);
+    pub fn with_purchase_order_uid(mut self, po_uid: String) -> Self {
+        self.purchase_order_uid = Some(po_uid);
         self
     }
 
@@ -824,20 +970,21 @@ impl PurchaseOrderAlternateIdBuilder {
             PurchaseOrderAlternateIdBuildError::MissingField("'id' field is required".to_string())
         })?;
 
-        let org_id = self.org_id.ok_or_else(|| {
+        let purchase_order_uid = self.purchase_order_uid.ok_or_else(|| {
             PurchaseOrderAlternateIdBuildError::MissingField(
-                "'org_id' field is required".to_string(),
+                "'purchase_order_uid' field is required".to_string(),
             )
         })?;
 
         Ok(PurchaseOrderAlternateId {
             id_type,
             id,
-            org_id,
+            purchase_order_uid,
         })
     }
 }
 
+/// Native representation of a list of `PurchaseOrderAlternateId`s
 #[derive(Debug, Clone, PartialEq)]
 pub struct PurchaseOrderAlternateIdList {
     alternate_ids: Vec<PurchaseOrderAlternateId>,
@@ -929,6 +1076,7 @@ impl IntoNative<PurchaseOrderAlternateIdList>
 {
 }
 
+/// Builder used to create a list of `PurchaseOrderAlternateId`s
 #[derive(Default, Clone)]
 pub struct PurchaseOrderAlternateIdListBuilder {
     alternate_ids: Option<Vec<PurchaseOrderAlternateId>>,
