@@ -14,9 +14,18 @@
 
 pub(super) mod add_alternate_id;
 pub(super) mod add_purchase_order;
+mod add_purchase_order_version;
+mod add_purchase_order_version_revision;
+pub(super) mod get_latest_revision_id;
 pub(super) mod get_purchase_order;
+pub(super) mod get_purchase_order_version;
+pub(super) mod get_purchase_order_version_revision;
+mod get_uid_from_alternate_id;
 pub(super) mod list_alternate_ids_for_purchase_order;
+pub(super) mod list_purchase_order_version_revisions;
+pub(super) mod list_purchase_order_versions;
 pub(super) mod list_purchase_orders;
+mod remove_alternate_id;
 
 pub(super) struct PurchaseOrderStoreOperations<'a, C> {
     conn: &'a C,
